import java.io.*;
import java.util.*;
import java.text.*;
import static java.lang.Math.*;

public class D
{
    public BufferedReader br;
    public PrintStream ps;

    public String toString()
    {
        return "D";
    }

    public static final double EPS = 0.0000000001;

    public boolean eq( double a, double b )
    {
        return abs(a-b)<EPS;
    }

    public class LineSegment
    {
        public double x1, y1, x2, y2, angle;

        public LineSegment( double xa, double ya, double xb, double yb )
        {
            if( xa<xb || (eq(xa,xb) && ya<yb ))
            {
                x1=xa; y1=ya; x2=xb; y2=yb;
            }
            else
            {
                x1=xb; y1=yb; x2=xa; y2=ya;
            }

            angle = atan2( y2-y1, x2-x1 );
        }

        public String toString()
        {
            return "{LS:x1=" + x1 + ",y1=" + y1 + ",x2=" + x2 + ",y2=" + y2 + ",angle=" + angle + "}";
        }

        public boolean intersects( LineSegment ls )
        {
            boolean ok = false;
            if( eq( angle, ls.angle ) && x1<=ls.x2 && ls.x1<=x2 && y1<=ls.y2 && ls.y1<=y2 )
            {
                ok = true;
            }
            //System.out.println( "Checking intersection: " + this + " with " + ls + " result " + ok  );

            return ok;
        }

        public void merge( LineSegment ls )
        {
            if( ls.x1<x1 || (eq(ls.x1,x1) && ls.y1<y1 ) )
            {
                x1 = ls.x1;
                y1 = ls.y1;
            }

            if( ls.x2>x2 || (eq(ls.x2,x2) && ls.y2>y2) )
            {
                x2 = ls.x2;
                y2 = ls.y2;
            }
        }
    };
    
    public void doit() throws Exception
    {
        int i, j, k;
        String tokens[];

        br = new BufferedReader( new FileReader( "D.dat" ) );
        ps = new PrintStream( new FileOutputStream( "D.out" ) );

        for(;;)
        {
            int n = Integer.parseInt( br.readLine().trim() );
            if( n==0 ) break;

            LinkedList<LineSegment> segs = new LinkedList<LineSegment>();
            for( i=0; i<n; i++ )
            {
                tokens = br.readLine().trim().split( "\\s+" );
                double x1 = Double.parseDouble( tokens[0] );
                double y1 = Double.parseDouble( tokens[1] );
                double x2 = Double.parseDouble( tokens[2] );
                double y2 = Double.parseDouble( tokens[3] );

                segs.add( new LineSegment( x1, y1, x2, y2 ) );
            }

            if( n==10000 )System.out.println( segs );

            int failcount = 0;
            while( failcount<segs.size() )
            {
                ++failcount;
                LineSegment s1 = segs.poll();
                for( LineSegment s2 : segs )
                {
                    if( s2.intersects( s1 ) )
                    {
                        s2.merge( s1 );
                        s1 = null;
                        failcount=0;
                        break;
                    }
                }

                if( s1!=null )
                {
                    segs.add( s1 );
                }
            }

            ps.println( segs.size() );
            System.out.println( segs.size() );
        }
    }

    public static void main( String args[] ) throws Exception
    {
        try
        {
            (new D()).doit();
        }
        catch( Exception e )
        {
            e.printStackTrace();
        }
    }
};
