import java.io.*;
import java.util.*;
import java.text.*;

public class H
{
    public BufferedReader br;
    public PrintStream ps;

    public String toString()
    {
        return "H";
    }

    public int n;

    public class Move
    {
        public Entry entry;
        public int dist;

        public Move( Entry e, int d )
        {
            entry = e;
            dist = d;
        }

        public String toString()
        {
            return "{Move:entry=" + entry + ",dist=" + dist + "}";
        }
    };

    public class Entry implements Comparable
    {
        public String word, trans;
        public PriorityQueue<String> prewords, postwords, pretrans, posttrans; 
        public LinkedList<Entry> pre, post;
        public String sig, base;
        public boolean visited;

        public Entry( String w )
        {
            word = w;
            trans = null;
            prewords = new PriorityQueue<String>();
            postwords = new PriorityQueue<String>();
            pretrans = new PriorityQueue<String>();
            posttrans = new PriorityQueue<String>();
            pre = new LinkedList<Entry>();
            post = new LinkedList<Entry>();
            sig = "";
            base = "";
            visited = false;
        }

        public String toString()
        {
            return "{Entry:word=" + word + ",trans=" + trans
                + ",prewords=" + prewords + ",postwords=" + postwords
                + ",pretrans=" + pretrans + ",posttrans=" + posttrans + "}";
        }

        public void buildbase()
        {
            HashSet intersection = new HashSet( prewords );
            intersection.retainAll( postwords );
            base =  "{" + prewords.size() + ":" + postwords.size()
                + ":" + intersection.size() + "}";
        }

        public String buildsig( Collection<Entry> adj, Collection<Entry> words )
        {
            int i;
            LinkedList sigs[] = new LinkedList[n];
            String result = "";

            for( i=0; i<n; i++ )
            {
                sigs[i] = new LinkedList<String>();
            }

            for( Entry e : words )
            {
                e.visited = false;
            }

            LinkedList<Move> queue = new LinkedList<Move>();

            queue.add( new Move( this, 0 ) );
            while( queue.size()>0 )
            {
                Move m = queue.poll();
                if( !m.entry.visited )
                {
                    m.entry.visited = true;
                    sigs[m.dist].add( m.entry.base );

                    for( Entry e : adj ) if( !e.visited )
                    {
                        queue.add( new Move( e, m.dist+1 ) );
                    }
                }
            }

            result = "";
            for( i=0; i<n; i++ )
            {
                Collections.sort( sigs[i] );
                result += sigs[i];
            }

            return result;
        }

        public String sig()
        {
            return sig + pretrans + posttrans;
        }

        public String report()
        {
            return word + "/" + (trans==null?"???":trans);
        }

        public int compareTo( Object o )
        {
            Entry e = (Entry)o;
            return word.compareTo( e.word );
        }
    };
    
    public void doit() throws Exception
    {
        int i, j;
        String tokens[];

        br = new BufferedReader( new FileReader( "H.dat" ) );
        ps = new PrintStream( new FileOutputStream( "H.out" ) );

        for(;;)
        {
            n = Integer.parseInt( br.readLine().trim() );
            if( n==0 ) break;

            Hashtable<String,Entry> dict = new Hashtable<String,Entry>();

            for( i=0; i<n; i++ )
            {
                tokens = br.readLine().trim().split( "\\s+" );

                Entry w1 = dict.get( tokens[0] );
                if( w1==null )
                {
                    w1 = new Entry( tokens[0] );
                    dict.put( w1.word, w1 );
                }

                Entry w2 = dict.get( tokens[1] );
                if( w2==null )
                {
                    w2 = new Entry( tokens[1] );
                    dict.put( w2.word, w2 );
                }

                w1.postwords.add( w2.word );
                w2.prewords.add( w1.word );
                w1.post.add( w2 );
                w2.pre.add( w1 );
            }

            Hashtable<String,Entry> trans = new Hashtable<String,Entry>();

            for( i=0; i<n; i++ )
            {
                tokens = br.readLine().trim().split( "\\s+" );

                Entry w1 = trans.get( tokens[0] );
                if( w1==null )
                {
                    w1 = new Entry( tokens[0] );
                    trans.put( w1.word, w1 );
                }

                Entry w2 = trans.get( tokens[1] );
                if( w2==null )
                {
                    w2 = new Entry( tokens[1] );
                    trans.put( w2.word, w2 );
                }

                w1.postwords.add( w2.word );
                w2.prewords.add( w1.word );
                w1.post.add( w2 );
                w2.pre.add( w1 );
            }

            for( Entry e : dict.values() )
            {
                e.buildbase();
            }

            for( Entry e : dict.values() )
            {
                e.sig = e.buildsig( e.post, dict.values() );
                e.sig += e.buildsig( e.pre, dict.values() );
            }

            for( Entry e : trans.values() )
            {
                e.buildbase();
            }

            for( Entry e : trans.values() )
            {
                e.sig = e.buildsig( e.post, trans.values() );
                e.sig += e.buildsig( e.pre, trans.values() );
            }

            boolean more = true;
            while( more )
            {
                more = false;

                Hashtable<String,Entry> sigs = new Hashtable<String,Entry>();
                HashSet<String> seen = new HashSet<String>();
                HashSet<String> single = new HashSet<String>();

                for( Entry e : dict.values() ) if( e.trans==null )
                {
                    String signature = e.sig();
                    if( seen.contains( signature ) )
                    {
                        if( single.contains( signature ) )
                        {
                            single.remove( signature );
                        }
                    }
                    else
                    {
                        seen.add( signature );
                        single.add( signature );
                    }
                }

                for( Entry e : trans.values() ) if( e.trans==null )
                {
                    sigs.put( e.sig(), e );
                }

                for( Entry e : dict.values() ) if( single.contains( e.sig() ) )
                {
                    Entry t = sigs.get( e.sig() );
                    if( t==null )
                    {
                        System.out.println( "ACK! No match for " + e.sig() );
                        continue;
                    }
                    e.trans = t.word;
                    t.trans = e.word;
                    more = true;

                    for( Entry ee : dict.values() )
                    {
                        if( ee.prewords.contains( e.word ) )
                        {
                            ee.pretrans.add( t.word );
                        }
                        if( ee.postwords.contains( e.word ) )
                        {
                            ee.posttrans.add( t.word );
                        }
                    }

                    for( Entry ee : trans.values() )
                    {
                        if( ee.prewords.contains( t.word ) )
                        {
                            ee.pretrans.add( t.word );
                        }
                        if( ee.postwords.contains( t.word ) )
                        {
                            ee.posttrans.add( t.word );
                        }
                    }
                }
            }

            LinkedList<Entry> sorter = new LinkedList<Entry>( dict.values() );
            Collections.sort( sorter );

            for( Entry e : sorter )
            {
                ps.println( e.report() );
            }
            ps.println();
        }
    }

    public static void main( String args[] ) throws Exception
    {
        try
        {
            (new H()).doit();
        }
        catch( Exception e )
        {
            e.printStackTrace();
        }
    }
};
